import { ComponentConfig } from './directive-config';
import { ModuleConfig } from './module-config';
import { TextWriter } from '@yellicode/templating';
import { TypeScriptWriter } from '@yellicode/typescript';
/**
 * Provides utility functions for generating Angular 2+ application code.
 */
export declare class AngularWriter {
    /**
    * Writes a full Angular '@Component' class decorator using the provided configuration.
    */
    static writeComponentDecorator(writer: TypeScriptWriter, config: ComponentConfig): void;
    /**
     * Writes Angular component configuration that can be used inside a component class decorator.
     * Use writeComponentDecorator() to write a full '@Component' class decorator.
     */
    static writeComponentConfig(writer: TextWriter, config: ComponentConfig): void;
    /**
    * Writes a full Angular '@NgModule' class decorator using the provided configuration.
    */
    static writeModuleDecorator(writer: TypeScriptWriter, config: ModuleConfig): void;
    /**
     * Writes Angular module configuration that can be used inside a module class decorator.
     * Use writeModuleDecorator() to write a full '@NgModule' class decorator.
     */
    static writeModuleConfig(writer: TextWriter, config: ModuleConfig): void;
    /**
    * Writes a route configuration for the specified component, with the specified route path.
    */
    static writeRoute(writer: TextWriter, route: {
        path: string;
        componentName: string;
    }): void;
    private static stringifyModuleProperty;
    private static stringifyComponentProperty;
    private static stringifyObjectArray;
    private static stringifyStringArray;
    private static stringifyKeyValuePair;
}
